OC.L10N.register(
    "bookmarks",
    {
    "Select bookmark" : "Chọn bookmark",
    "Details" : "Thông tin",
    "Rename" : "Đổi tên",
    "Move" : "Dịch chuyển",
    "Delete" : "Xóa",
    "Select all" : "Chọn tất cả",
    "Select one or more tags" : "Chọn một hoặc nhiều thẻ",
    "New" : "Tạo mới",
    "New folder" : "Tạo thư mục",
    "Enter folder title" : "Nhập tiêu đề thư mục",
    "Submit" : "Gửi đi",
    "Cancel" : "Hủy bỏ",
    "Recent" : "Gần đây",
    "Import" : "Nhập vào",
    "Export" : "Xuất ra",
    "Clear data" : "Xóa dữ liệu",
    "Title" : "Tên",
    "Link" : "Liên kết",
    "Tags" : "Thẻ",
    "Notes" : "Ghi chép",
    "Owner" : "Chủ",
    "Sharing" : "Đang chia sẽ",
    "Share link" : "Chia sẽ liên kết",
    "Copy link" : "Sao chép liên kết",
    "Allow editing" : "Cho phép chỉnh sửa",
    "Privacy" : "Riêng tư",
    "Failed to load settings" : "Tải cấu hình thất bại",
    "Failed to save settings" : "Lưu cấu hình thất bại",
    "Add a bookmark" : "Thêm một bookmark",
    "Enter bookmark title" : "Nhập tiêu đề bookmark",
    "Folder" : "Thư mục",
    "Root Folder" : "Thư mục gốc",
    "Save" : "Lưu"
},
"nplurals=1; plural=0;");
